@@ -2,7 +2,7 @@ package MVC::Neaf::Route::Main;
 
 use strict;
 use warnings;
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 =head1 NAME
 
@@ -21,17 +21,31 @@ containing a hash of other routes designated by their path prefixes.
 =cut
 
 use Carp;
+use Cwd qw(cwd abs_path);
 use Encode;
+use File::Basename qw(dirname);
 use Module::Load;
 use Scalar::Util qw( blessed looks_like_number reftype );
 use URI::Escape;
 
 use parent qw(MVC::Neaf::Route);
-use MVC::Neaf::Util qw( run_all run_all_nodie http_date canonize_path check_path
-     maybe_list supported_methods extra_missing encode_b64 decode_b64 data_fh );
-use MVC::Neaf::Util::Container;
 use MVC::Neaf::Request::PSGI;
 use MVC::Neaf::Route::PreRoute;
+use MVC::Neaf::Util qw(
+    caller_info
+    canonize_path
+    check_path
+    data_fh
+    decode_b64
+    encode_b64
+    extra_missing
+    http_date
+    maybe_list
+    run_all
+    run_all_nodie
+    supported_methods
+);
+use MVC::Neaf::Util::Container;
 
 # TODO 0.30 remove
 sub _one_and_true {
@@ -391,7 +405,7 @@ This is not enforced whatsoever.
 
 =back
 
-See L<MVC::Meaf::X::Files> for implementation.
+See L<MVC::Neaf::X::Files> for implementation.
 
 File type detection is based on extentions so far, and the list is quite short.
 This MAY change in the future.
@@ -423,7 +437,7 @@ sub static {
 
     require MVC::Neaf::X::Files;
     my $xfiles = MVC::Neaf::X::Files->new(
-        %options, root => $dir, base_url => $path );
+        %options, root => $self->dir($dir), base_url => $path );
     return $self->route( $xfiles->make_route, %fwd_opt );
 };
 
@@ -799,7 +813,7 @@ sub load_view {
             eval { load $obj; 1 }
                 or $self->my_croak( "Failed to load view $name=>$obj: $@" );
         };
-        $obj = $obj->new( @param );
+        $obj = $obj->new( neaf_base_dir => $self->neaf_base_dir, @param );
     };
 
     $self->my_croak( "view must be a coderef or a MVC::Neaf::View object" )
@@ -1798,6 +1812,29 @@ sub _get_error_handler {
     return $store->fetch_last( method => $req->method, path => $req->path );
 };
 
+=head2 neaf_base_dir()
+
+Returns the containing directory of the first non-Neaf calling file,
+or cwd() with a warning otherwise.
+
+=cut
+
+# Should we cache? If so, how to determine we're in a different file now?
+sub neaf_base_dir {
+    my $self = shift;
+
+    my $file = caller_info()->[1];
+    if (defined $file and -f $file) {
+        $file = abs_path($file);
+        # TODO actually don't use magic, add use param instead
+        return $file =~ /(.*)\.pm$/ ? $1 : dirname $file;
+    };
+
+    my $cwd = cwd;
+    carp "Unable to determine relative path via caller, consider using absolute paths. Defaulting to cwd='$cwd'";
+    return $cwd;
+};
+
 =head1 DEPRECATED METHODS
 
 Some methods become obsolete during Neaf development.
@@ -1831,7 +1868,7 @@ sub route {
 
 This module is part of L<MVC::Neaf> suite.
 
-Copyright 2016-2019 Konstantin S. Uvarin C<khedin@cpan.org>.
+Copyright 2016-2023 Konstantin S. Uvarin C<khedin@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
